==> owncloud-8.2.5.tar.bz2: owncloud/apps/files_sharing/l10n/bn_BD.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "এই সার্ভারে সার্ভার হতে সার্ভারে ভাগাভাগি কার্যকর নয়",
    "Invalid or untrusted SSL certificate" : "অবৈধ বা অবিশ্বস্ত SSL সার্টিফিকেট",
    "Couldn't add remote share" : "দুরবর্তী ভাগাভাগি যোগ করা গেলনা",
    "Shared with you" : "আপনার সাথে ভাগাভাগি করেছেন",
    "Shared by link" : "লিঙ্কের মাধ্যমে ভাগাভাগিকৃত",
    "Remote share" : "দুরবর্তী ভাগাভাগি",
    "Cancel" : "বাতিল",
    "Invalid ownCloud url" : "অবৈধ ওউনক্লাউড url",
    "Shared by" : "যাদের মাঝে ভাগাভাগি করা হয়েছে",
    "Sharing" : "ভাগাভাগিরত",
    "A file or folder has been <strong>shared</strong>" : "একটি ফাইল বা ফোলডার <strong>ভাগাভাগি</strong> করা হয়েছে",
    "You shared %1$s with %2$s" : "আপনি %1$sকে %2$sএর সাথে ভাগাভাগি করেছেন",
    "You shared %1$s with group %2$s" : "আপনি %1$s কে %2$s দলের সাথে ভাগাভাগি করেছেন",
    "%2$s shared %1$s with you" : "%2$s আপনার সাথে %1$s ভাগাভাগি করেছেন",
    "You shared %1$s via link" : "আপনি %1$s লিংকের মাধধমে ভাগাভাগি করেছেন",
    "Shares" : "ভাগাভাগি",
    "This share is password-protected" : "এই শেয়ারটি কূটশব্দদ্বারা সুরক্ষিত",
    "The password is wrong. Try again." : "কুটশব্দটি ভুল। আবার চেষ্টা করুন।",
    "Password" : "কূটশব্দ",
    "Name" : "নাম",
    "Share time" : "ভাগাভাগির সময়",
    "Sorry, this link doesn’t seem to work anymore." : "দুঃখিত, এই লিঙ্কটি আর কার্যকর নয়।",
    "Reasons might be:" : "কারণসমূহ হতে পারে:",
    "the item was removed" : "আইটেমটি অপসারণ করা হয়েছিল",
    "the link expired" : "মেয়াদোত্তীর্ন লিঙ্ক",
    "sharing is disabled" : "ভাগাভাগি অকার্যকর",
    "For more info, please ask the person who sent this link." : "বিস্তারিত তথ্যের জন্য এই লিঙ্কের প্রেরককে জিজ্ঞাসা করুন।",
    "Download" : "ডাউনলোড",
    "Download %s" : "ডাউনলোড  %s",
    "Direct link" : "সরাসরি লিঙ্ক"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.7.0.tar.bz2: owncloud/apps/files_sharing/l10n/bn_BD.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "এই সার্ভারে সার্ভার হতে সার্ভারে ভাগাভাগি কার্যকর নয়",
    "Couldn't add remote share" : "দুরবর্তী ভাগাভাগি যোগ করা গেলনা",
    "Shared with you" : "আপনার সাথে ভাগাভাগি করেছেন",
    "Shared by link" : "লিঙ্কের মাধ্যমে ভাগাভাগিকৃত",
    "Uploading..." : "আপলোড করা হচ্ছে..........",
    "Remote share" : "দুরবর্তী ভাগাভাগি",
    "Cancel" : "বাতিল",
    "Invalid ownCloud url" : "অবৈধ ওউনক্লাউড url",
    "Share" : "ভাগাভাগি কর",
    "Pending" : "মুলতুবি",
    "Shared by" : "যাদের মাঝে ভাগাভাগি করা হয়েছে",
    "Sharing" : "ভাগাভাগিরত",
    "A file or folder has been <strong>shared</strong>" : "একটি ফাইল বা ফোলডার <strong>ভাগাভাগি</strong> করা হয়েছে",
    "You shared %1$s with %2$s" : "আপনি %1$sকে %2$sএর সাথে ভাগাভাগি করেছেন",
    "You shared %1$s with group %2$s" : "আপনি %1$s কে %2$s দলের সাথে ভাগাভাগি করেছেন",
    "You shared %1$s via link" : "আপনি %1$s লিংকের মাধধমে ভাগাভাগি করেছেন",
    "%2$s shared %1$s with you" : "%2$s আপনার সাথে %1$s ভাগাভাগি করেছেন",
    "Shares" : "ভাগাভাগি",
    "This share is password-protected" : "এই শেয়ারটি কূটশব্দদ্বারা সুরক্ষিত",
    "The password is wrong. Try again." : "কুটশব্দটি ভুল। আবার চেষ্টা করুন।",
    "Password" : "কূটশব্দ",
    "Name" : "নাম",
    "Share time" : "ভাগাভাগির সময়",
    "Expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ",
    "Sorry, this link doesn’t seem to work anymore." : "দুঃখিত, এই লিঙ্কটি আর কার্যকর নয়।",
    "Reasons might be:" : "কারণসমূহ হতে পারে:",
    "the item was removed" : "আইটেমটি অপসারণ করা হয়েছিল",
    "the link expired" : "মেয়াদোত্তীর্ন লিঙ্ক",
    "sharing is disabled" : "ভাগাভাগি অকার্যকর",
    "For more info, please ask the person who sent this link." : "বিস্তারিত তথ্যের জন্য এই লিঙ্কের প্রেরককে জিজ্ঞাসা করুন।",
    "Download" : "ডাউনলোড",
    "Download %s" : "ডাউনলোড  %s",
    "Direct link" : "সরাসরি লিঙ্ক"
},
"nplurals=2; plural=(n != 1);");
